#include <Arduino.h>

#include <SPI.h>
#include <RFID.h>
#include <Wire.h>
#include <Adafruit_I2CDevice.h>
#include <Adafruit_SSD1306.h>
#include <Adafruit_GFX.h>

#define SCREEN_WIDTH 128 // OLED display width,  in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels

#define SS_PIN 10
#define RST_PIN 9
RFID rfid(SS_PIN, RST_PIN);
Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);
String rfidCard;

void OLED_Timer();
void Start_Motor();
void Stop_Motor();

float a;
float x = 60.02;
float b = 0.02;
int s;
byte Starting_Number = 1;
char Ending_Number = 0;

void setup()
{
  Wire.begin();
  Serial.begin(9600);
  Serial.println("Starting the RFID Reader...");
  oled.begin(SSD1306_SWITCHCAPVCC, 0x3C);
  SPI.begin();
  rfid.init();
  pinMode(13,OUTPUT);
  pinMode(12, OUTPUT);
  pinMode(4, OUTPUT);
  pinMode(3, OUTPUT);
}

void loop()
{
  oled.clearDisplay();      // clear display
  oled.setTextSize(3);      // text size
  oled.setTextColor(WHITE); // text color
  oled.setCursor(24, 20);
  oled.print("RFID?");
  oled.display();

  if (rfid.isCard())
  {
    if (rfid.readCardSerial())
    {
      rfidCard = String(rfid.serNum[0]) + " " + String(rfid.serNum[1]) + " " + String(rfid.serNum[2]) + " " + String(rfid.serNum[3]);
      Serial.println(rfidCard);
      if (rfidCard == "124 98 66 24")
      {
        delay(200);
        Start_Motor();
        OLED_Timer();
      }
    }
    rfid.halt();
  }
}

void OLED_Timer()
{  
  for (int i = 0; i <= 2995; i++)
  {
    x = x - b;
    a = x - b;
    delay(5);
    oled.clearDisplay();      // clear display
    oled.setTextSize(3);      // text size
    oled.setTextColor(WHITE); // text color
    oled.setCursor(24, 20);
    oled.print(a);
    oled.display();
  }

  Stop_Motor();

  x = 60.02;
  oled.clearDisplay();      // clear display
  oled.setTextSize(2);      // text size
  oled.setTextColor(WHITE); // text color
  oled.setCursor(24, 20);
  oled.print("Thanks!");
  oled.display();
  delay(5000);
}



void Start_Motor() {
  Wire.beginTransmission(2);
  Wire.write(Starting_Number);
  Wire.endTransmission();
  Serial.println(Starting_Number);
}

void Stop_Motor() {
  Wire.beginTransmission(2);
  Wire.write(Ending_Number);
  Wire.endTransmission();
}

